@@ -17,6 +17,9 @@
 #endif
 
 void saveBtDeviceInfo(const QString &devaddr, QBluetoothDeviceInfo deviceInfo);
+bool isBluetoothAddress(const QString &address);
+QString extractBluetoothAddress(const QString &address);
+QString extractBluetoothNameAddress(const QString &address, QString &name);
 QBluetoothDeviceInfo getBtDeviceInfo(const QString &devaddr);
 
 class BTDiscovery : public QObject {
@@ -48,6 +51,7 @@ public:
 	QList<btVendorProduct> getBtDcs();
 	QBluetoothLocalDevice localBtDevice;
 	void BTDiscoveryReDiscover();
+	void discoverAddress(QString address);
 
 private:
 	static BTDiscovery *m_instance;
