@@ -63,7 +63,7 @@ bool CheckCloudConnection::checkServer()
 		}
 	}
 	git_storage_update_progress(qPrintable(tr("Cloud connection failed")));
-	prefs.git_local_only = true;
+	git_local_only = true;
 	if (verbose)
 		qDebug() << "connection test to cloud server failed" <<
 			    reply->error() << reply->errorString() <<
