@@ -8,7 +8,7 @@ extern "C" {
 
 extern double buehlmann_N2_t_halflife[];
 
-extern int deco_allowed_depth(double tissues_tolerance, double surface_pressure, struct dive *dive, bool smooth);
+extern int deco_allowed_depth(double tissues_tolerance, double surface_pressure, const struct dive *dive, bool smooth);
 
 double get_gf(struct deco_state *ds, double ambpressure_bar, const struct dive *dive);
 
