@@ -22,12 +22,6 @@ typedef struct
 	double phe_threshold;
 } partial_pressure_graphs_t;
 
-typedef struct {
-	const char *access_token;
-	const char *user_id;
-	const char *album_id;
-} facebook_prefs_t;
-
 typedef struct {
 	enum taxonomy_category category[3];
 } geocoding_prefs_t;
@@ -111,9 +105,6 @@ struct preferences {
 	double      mobile_scale;
 	bool        show_developer;
 
-	// ********** Facebook **********
-	facebook_prefs_t facebook;
-
 	// ********** General **********
 	bool        auto_recalculate_thumbnails;
 	bool	    extract_video_thumbnails;
