@@ -464,10 +464,7 @@ static void save_picture(struct membuffer *b, struct picture *pic)
 		}
 		put_format(b, " offset='%c%u:%02u min'", sign, FRACTION(offset, 60));
 	}
-	if (pic->latitude.udeg || pic->longitude.udeg) {
-		put_degrees(b, pic->latitude, " gps='", " ");
-		put_degrees(b, pic->longitude, "", "'");
-	}
+	put_location(b, &pic->location, " gps='","'");
 
 	put_string(b, "/>\n");
 }
@@ -486,11 +483,8 @@ void save_one_dive_to_mb(struct membuffer *b, struct dive *dive, bool anonymize)
 	if (dive->visibility)
 		put_format(b, " visibility='%d'", dive->visibility);
 	save_tags(b, dive->tag_list);
-	if (dive->dive_site_uuid) {
-		if (get_dive_site_by_uuid(dive->dive_site_uuid) != NULL)
-			put_format(b, " divesiteid='%8x'", dive->dive_site_uuid);
-		else if (verbose)
-			fprintf(stderr, "removed reference to non-existant dive site with uuid %08x\n", dive->dive_site_uuid);
+	if (dive->dive_site) {
+		put_format(b, " divesiteid='%8x'", dive->dive_site->uuid);
 	}
 	show_date(b, dive->when);
 	if (dive->dc.duration.seconds > 0)
@@ -603,12 +597,12 @@ void save_dives_buffer(struct membuffer *b, const bool select_only, bool anonymi
 		int j;
 		struct dive *d;
 		struct dive_site *ds = get_dive_site(i);
-		if (dive_site_is_empty(ds) || !is_dive_site_used(ds->uuid, false)) {
+		if (dive_site_is_empty(ds) || !is_dive_site_used(ds, false)) {
 			for_each_dive(j, d) {
-				if (d->dive_site_uuid == ds->uuid)
-					d->dive_site_uuid = 0;
+				if (d->dive_site == ds)
+					d->dive_site = NULL;
 			}
-			delete_dive_site(ds->uuid);
+			delete_dive_site(ds);
 			i--; // since we just deleted that one
 			continue;
 		} else if (ds->name &&
@@ -617,23 +611,20 @@ void save_dives_buffer(struct membuffer *b, const bool select_only, bool anonymi
 			// these are the two default names for sites from
 			// the web service; if the site isn't used in any
 			// dive (really? you didn't rename it?), delete it
-			if (!is_dive_site_used(ds->uuid, false)) {
+			if (!is_dive_site_used(ds, false)) {
 				if (verbose)
 					fprintf(stderr, "Deleted unused auto-created dive site %s\n", ds->name);
-				delete_dive_site(ds->uuid);
+				delete_dive_site(ds);
 				i--; // since we just deleted that one
 				continue;
 			}
 		}
-		if (select_only && !is_dive_site_used(ds->uuid, true))
+		if (select_only && !is_dive_site_used(ds, true))
 				continue;
 
 		put_format(b, "<site uuid='%8x'", ds->uuid);
 		show_utf8_blanked(b, ds->name, " name='", "'", 1, anonymize);
-		if (ds->latitude.udeg || ds->longitude.udeg) {
-			put_degrees(b, ds->latitude, " gps='", " ");
-			put_degrees(b, ds->longitude, "", "'");
-		}
+		put_location(b, &ds->location, " gps='", "'");
 		show_utf8_blanked(b, ds->description, " description='", "'", 1, anonymize);
 		put_format(b, ">\n");
 		show_utf8_blanked(b, ds->notes, "  <notes>", " </notes>\n", 0, anonymize);
