@@ -2,6 +2,7 @@
 #ifndef MAPWIDGET_H
 #define MAPWIDGET_H
 
+#include "core/units.h"
 #include <QQuickWidget>
 #include <QList>
 
@@ -24,21 +25,21 @@ public:
 	void reload();
 
 signals:
-	void coordinatesChanged();
+	void coordinatesChanged(const location_t &);
 
 public slots:
+	void centerOnSelectedDiveSite();
 	void centerOnDiveSite(struct dive_site *);
 	void centerOnIndex(const QModelIndex& idx);
 	void endGetDiveCoordinates();
 	void repopulateLabels();
-	void prepareForGetDiveCoordinates();
+	void prepareForGetDiveCoordinates(struct dive_site *ds);
 	void selectedDivesChanged(QList<int>);
-	void coordinatesChangedLocal();
+	void coordinatesChangedLocal(const location_t &);
 	void doneLoading(QQuickWidget::Status status);
-	void updateCurrentDiveSiteCoordinatesToMap();
+	void updateDiveSiteCoordinates(struct dive_site *ds, const location_t &);
 
 private:
-	void setEditMode(bool editMode);
 	static MapWidget *m_instance;
 	QQuickItem *m_rootItem;
 	MapWidgetHelper *m_mapHelper;
