@@ -59,7 +59,7 @@ public:
 signals:
 	void addDiveFinished();
 	void dateTimeChanged();
-	void diveSiteChanged(struct dive_site * ds);
+	void diveSiteChanged();
 public
 slots:
 	void addCylinder_clicked();
@@ -97,9 +97,6 @@ slots:
 	void toggleTriggeredColumn();
 	void updateTextLabels(bool showUnits = true);
 	void escDetected(void);
-	void showLocation();
-	void enableGeoLookupEdition();
-	void disableGeoLookupEdition();
 	void setCurrentLocationIndex();
 	EditMode getEditMode() const;
 private:
@@ -118,14 +115,15 @@ private:
 	int lastTabSelectedDive;
 	int lastTabSelectedDiveTrip;
 	void resetPallete();
-	void saveTags();
-	void saveTaggedStrings();
-	void diffTaggedStrings(QString currentString, QString displayedString, QStringList &addedList, QStringList &removedList);
+	void copyTagsToDisplayedDive();
+	void saveTags(const QVector<dive *> &selectedDives);
+	void saveTaggedStrings(const QVector<dive *> &selectedDives);
+	int diffTaggedStrings(QString currentString, QString displayedString, QStringList &addedList, QStringList &removedList);
 	void markChangedWidget(QWidget *w);
 	dive_trip_t *currentTrip;
 	dive_trip_t displayedTrip;
 	bool acceptingEdit;
-	uint32_t updateDiveSite(uint32_t pickedUuid, int divenr);
+	struct dive_site *updateDiveSite(struct dive_site *pickedDs, dive *d);
 	QList<TabBase*> extraWidgets;
 };
 
