@@ -22,72 +22,61 @@ MapWidgetHelper::MapWidgetHelper(QObject *parent) : QObject(parent)
 	        this, SLOT(selectedLocationChanged(MapLocation *)));
 }
 
-QGeoCoordinate MapWidgetHelper::getCoordinatesForUUID(QVariant dive_site_uuid)
+QGeoCoordinate MapWidgetHelper::getCoordinates(struct dive_site *ds)
 {
-	const uint32_t uuid = qvariant_cast<uint32_t>(dive_site_uuid);
-	struct dive_site *ds = get_dive_site_by_uuid(uuid);
 	if (!ds || !dive_site_has_gps_location(ds))
 		return QGeoCoordinate(0.0, 0.0);
-	return QGeoCoordinate(ds->latitude.udeg * 0.000001, ds->longitude.udeg * 0.000001);
-}
-
-void MapWidgetHelper::centerOnDiveSiteUUID(QVariant dive_site_uuid)
-{
-	const uint32_t uuid = qvariant_cast<uint32_t>(dive_site_uuid);
-	struct dive_site *ds = get_dive_site_by_uuid(uuid);
-	if (ds)
-		centerOnDiveSite(ds);
+	return QGeoCoordinate(ds->location.lat.udeg * 0.000001, ds->location.lon.udeg * 0.000001);
 }
 
 void MapWidgetHelper::centerOnDiveSite(struct dive_site *ds)
+{
+	if (!ds || !dive_site_has_gps_location(ds)) {
+		// dive site with no GPS
+		m_mapLocationModel->setSelected(ds, false);
+		QMetaObject::invokeMethod(m_map, "deselectMapLocation");
+	} else {
+		// dive site with GPS
+		m_mapLocationModel->setSelected(ds, false);
+		QGeoCoordinate dsCoord (ds->location.lat.udeg * 0.000001, ds->location.lon.udeg * 0.000001);
+		QMetaObject::invokeMethod(m_map, "centerOnCoordinate", Q_ARG(QVariant, QVariant::fromValue(dsCoord)));
+	}
+}
+
+void MapWidgetHelper::centerOnSelectedDiveSite()
 {
 	QVector<struct dive_site *> selDS;
 	QVector<QGeoCoordinate> selGC;
-	QGeoCoordinate dsCoord;
 
-// selection of multiple dives is only possible on the desktop.
-// in the case of the mobile version only handle the passed dive_site.
-#ifndef SUBSURFACE_MOBILE
 	int idx;
 	struct dive *dive;
 	for_each_dive (idx, dive) {
+		if (!dive->selected)
+			continue;
 		struct dive_site *dss = get_dive_site_for_dive(dive);
-		if (!dive_site_has_gps_location(dss) || !dive->selected)
+		if (!dive_site_has_gps_location(dss))
 			continue;
 		// only store dive sites with GPS
 		selDS.append(dss);
-		selGC.append(QGeoCoordinate(dss->latitude.udeg * 0.000001,
-		                            dss->longitude.udeg * 0.000001));
+		selGC.append(QGeoCoordinate(dss->location.lat.udeg * 0.000001,
+		                            dss->location.lon.udeg * 0.000001));
 	}
-#else
-	if (dive_site_has_gps_location(ds)) {
-		selDS.append(ds);
-		selGC.append(QGeoCoordinate(ds->latitude.udeg * 0.000001,
-		                            ds->longitude.udeg * 0.000001));
-	}
-#endif
-	if (!dive_site_has_gps_location(ds) && !selDS.size()) {
-		// only a single dive site with no GPS selected
-		m_mapLocationModel->setSelectedUuid(ds ? ds->uuid : 0, false);
-		QMetaObject::invokeMethod(m_map, "deselectMapLocation");
 
+	if (selDS.isEmpty()) {
+		// no selected dives with GPS coordinates
+		m_mapLocationModel->setSelected(nullptr, false);
+		QMetaObject::invokeMethod(m_map, "deselectMapLocation");
 	} else if (selDS.size() == 1) {
-		// a single dive site with GPS selected
-		ds = selDS.at(0);
-		m_mapLocationModel->setSelectedUuid(ds->uuid, false);
-		dsCoord.setLatitude(ds->latitude.udeg * 0.000001);
-		dsCoord.setLongitude(ds->longitude.udeg * 0.000001);
-		QMetaObject::invokeMethod(m_map, "centerOnCoordinate", Q_ARG(QVariant, QVariant::fromValue(dsCoord)));
+		centerOnDiveSite(selDS[0]);
 	} else if (selDS.size() > 1) {
 		/* more than one dive sites with GPS selected.
 		 * find the most top-left and bottom-right dive sites on the map coordinate system. */
-		ds = selDS.at(0);
-		m_mapLocationModel->setSelectedUuid(ds->uuid, false);
+		m_mapLocationModel->setSelected(selDS[0], false);
 		qreal minLat = 0.0, minLon = 0.0, maxLat = 0.0, maxLon = 0.0;
 		bool start = true;
-		foreach(QGeoCoordinate gc, selGC) {
-			qreal lat = gc.latitude();
-			qreal lon = gc.longitude();
+		for(struct dive_site *dss: selDS) {
+			qreal lat = dss->location.lat.udeg * 0.000001;
+			qreal lon = dss->location.lon.udeg * 0.000001;
 			if (start) {
 				minLat = maxLat = lat;
 				minLon = maxLon = lon;
@@ -122,25 +111,19 @@ void MapWidgetHelper::reloadMapLocations()
 	m_mapLocationModel->clear();
 	MapLocation *location;
 	QVector<MapLocation *> locationList;
-	QVector<uint32_t> locationUuids;
+	QVector<struct dive_site *> locations;
 	qreal latitude, longitude;
 
-	if (displayed_dive_site.uuid && dive_site_has_gps_location(&displayed_dive_site)) {
-		latitude = displayed_dive_site.latitude.udeg * 0.000001;
-		longitude = displayed_dive_site.longitude.udeg * 0.000001;
-		location = new MapLocation(displayed_dive_site.uuid, QGeoCoordinate(latitude, longitude),
-		                           QString(displayed_dive_site.name));
-		locationList.append(location);
-		locationNameMap[QString(displayed_dive_site.name)] = location;
-	}
 	for_each_dive(idx, dive) {
-		if (dive->hidden_by_filter)
+		// Don't show dive sites of hidden dives, unless this is the currently
+		// displayed (edited) dive.
+		if (dive->hidden_by_filter && dive != current_dive)
 			continue;
 		struct dive_site *ds = get_dive_site_for_dive(dive);
-		if (!dive_site_has_gps_location(ds) || ds->uuid == displayed_dive_site.uuid || locationUuids.contains(ds->uuid))
+		if (!dive_site_has_gps_location(ds) || locations.contains(ds))
 			continue;
-		latitude = ds->latitude.udeg * 0.000001;
-		longitude = ds->longitude.udeg * 0.000001;
+		latitude = ds->location.lat.udeg * 0.000001;
+		longitude = ds->location.lon.udeg * 0.000001;
 		QGeoCoordinate dsCoord(latitude, longitude);
 		QString name(ds->name);
 		// don't add dive locations with the same name, unless they are
@@ -151,9 +134,9 @@ void MapWidgetHelper::reloadMapLocations()
 			if (dsCoord.distanceTo(coord) < MIN_DISTANCE_BETWEEN_DIVE_SITES_M)
 				continue;
 		}
-		location = new MapLocation(ds->uuid, dsCoord, name);
+		location = new MapLocation(ds, dsCoord, name);
 		locationList.append(location);
-		locationUuids.append(ds->uuid);
+		locations.append(ds);
 		locationNameMap[name] = location;
 	}
 	m_mapLocationModel->addList(locationList);
@@ -170,14 +153,14 @@ void MapWidgetHelper::selectedLocationChanged(MapLocation *location)
 		if (!dive_site_has_gps_location(ds))
 			continue;
 #ifndef SUBSURFACE_MOBILE
-		const qreal latitude = ds->latitude.udeg * 0.000001;
-		const qreal longitude = ds->longitude.udeg * 0.000001;
+		const qreal latitude = ds->location.lat.udeg * 0.000001;
+		const qreal longitude = ds->location.lon.udeg * 0.000001;
 		QGeoCoordinate dsCoord(latitude, longitude);
 		if (locationCoord.distanceTo(dsCoord) < m_smallCircleRadius)
 			m_selectedDiveIds.append(idx);
 	}
 #else // the mobile version doesn't support multi-dive selection
-		if (ds->uuid == location->uuid())
+		if (ds == location->divesite())
 			m_selectedDiveIds.append(dive->id); // use id here instead of index
 	}
 	int last; // get latest dive chronologically
@@ -200,15 +183,15 @@ void MapWidgetHelper::selectVisibleLocations()
 		struct dive_site *ds = get_dive_site_for_dive(dive);
 		if (!dive_site_has_gps_location(ds))
 			continue;
-		const qreal latitude = ds->latitude.udeg * 0.000001;
-		const qreal longitude = ds->longitude.udeg * 0.000001;
+		const qreal latitude = ds->location.lat.udeg * 0.000001;
+		const qreal longitude = ds->location.lon.udeg * 0.000001;
 		QGeoCoordinate dsCoord(latitude, longitude);
 		QPointF point;
 		QMetaObject::invokeMethod(m_map, "fromCoordinate", Q_RETURN_ARG(QPointF, point),
 		                          Q_ARG(QGeoCoordinate, dsCoord));
 		if (!qIsNaN(point.x())) {
 			if (!selectedFirst) {
-				m_mapLocationModel->setSelectedUuid(ds->uuid, false);
+				m_mapLocationModel->setSelected(ds, false);
 				selectedFirst = true;
 			}
 #ifndef SUBSURFACE_MOBILE // indexes on desktop
@@ -253,62 +236,68 @@ void MapWidgetHelper::calculateSmallCircleRadius(QGeoCoordinate coord)
 	m_smallCircleRadius = coord2.distanceTo(coord);
 }
 
+static location_t mk_location(QGeoCoordinate coord)
+{
+	return create_location(coord.latitude(), coord.longitude());
+}
+
 void MapWidgetHelper::copyToClipboardCoordinates(QGeoCoordinate coord, bool formatTraditional)
 {
 	bool savep = prefs.coordinates_traditional;
 	prefs.coordinates_traditional = formatTraditional;
-
-	const int lat = lrint(1000000.0 * coord.latitude());
-	const int lon = lrint(1000000.0 * coord.longitude());
-	const char *coordinates = printGPSCoords(lat, lon);
+	location_t location = mk_location(coord);
+	const char *coordinates = printGPSCoords(&location);
 	QApplication::clipboard()->setText(QString(coordinates), QClipboard::Clipboard);
 
 	free((void *)coordinates);
 	prefs.coordinates_traditional = savep;
 }
 
-void MapWidgetHelper::updateCurrentDiveSiteCoordinatesFromMap(quint32 uuid, QGeoCoordinate coord)
+void MapWidgetHelper::updateCurrentDiveSiteCoordinatesFromMap(struct dive_site *ds, QGeoCoordinate coord)
 {
-	MapLocation *loc = m_mapLocationModel->getMapLocationForUuid(uuid);
+	MapLocation *loc = m_mapLocationModel->getMapLocation(ds);
 	if (loc)
 		loc->setCoordinate(coord);
-	displayed_dive_site.latitude.udeg = lrint(coord.latitude() * 1000000.0);
-	displayed_dive_site.longitude.udeg = lrint(coord.longitude() * 1000000.0);
-	emit coordinatesChanged();
+	location_t location = mk_location(coord);
+	emit coordinatesChanged(location);
 }
 
-void MapWidgetHelper::updateCurrentDiveSiteCoordinatesToMap()
+void MapWidgetHelper::updateDiveSiteCoordinates(struct dive_site *ds, const location_t &location)
 {
-	const qreal latitude = displayed_dive_site.latitude.udeg * 0.000001;
-	const qreal longitude = displayed_dive_site.longitude.udeg * 0.000001;
-	QGeoCoordinate coord(latitude, longitude);
-	m_mapLocationModel->updateMapLocationCoordinates(displayed_dive_site.uuid, coord);
+	if (!ds)
+		return;
+	const qreal latitude_r = location.lat.udeg * 0.000001;
+	const qreal longitude_r = location.lon.udeg * 0.000001;
+	QGeoCoordinate coord(latitude_r, longitude_r);
+	m_mapLocationModel->updateMapLocationCoordinates(ds, coord);
 	QMetaObject::invokeMethod(m_map, "centerOnCoordinate", Q_ARG(QVariant, QVariant::fromValue(coord)));
 }
 
-bool MapWidgetHelper::editMode()
+void MapWidgetHelper::exitEditMode()
 {
-	return m_editMode;
+	m_editMode = false;
+	emit editModeChanged();
 }
 
-void MapWidgetHelper::setEditMode(bool editMode)
+void MapWidgetHelper::enterEditMode(struct dive_site *ds)
 {
-	m_editMode = editMode;
-	MapLocation *exists = m_mapLocationModel->getMapLocationForUuid(displayed_dive_site.uuid);
-	if (editMode) {
-		QGeoCoordinate coord;
-		// if divesite uuid doesn't exist in the model, add a new MapLocation.
-		if (!exists) {
-			coord = m_map->property("center").value<QGeoCoordinate>();
-			m_mapLocationModel->add(new MapLocation(displayed_dive_site.uuid, coord,
-			                                        QString(displayed_dive_site.name)));
-		} else {
-			coord = exists->coordinate();
-		}
-		displayed_dive_site.latitude.udeg = lrint(coord.latitude() * 1000000.0);
-		displayed_dive_site.longitude.udeg = lrint(coord.longitude() * 1000000.0);
-		emit coordinatesChanged();
+	// We don't support editing of a dive site that doesn't exist
+	if (!ds)
+		return;
+
+	m_editMode = true;
+	MapLocation *exists = m_mapLocationModel->getMapLocation(ds);
+	QGeoCoordinate coord;
+	// if divesite doesn't exist in the model, add a new MapLocation.
+	if (!exists) {
+		coord = m_map->property("center").value<QGeoCoordinate>();
+		m_mapLocationModel->add(new MapLocation(ds, coord, QString(ds->name)));
+	} else {
+		coord = exists->coordinate();
 	}
+	centerOnDiveSite(ds);
+	location_t location = mk_location(coord);
+	emit coordinatesChanged(location);
 	emit editModeChanged();
 }
 
