@@ -12,11 +12,22 @@ class DiveListSortModel : public QSortFilterProxyModel
 	Q_OBJECT
 public:
 	DiveListSortModel(QObject *parent = 0);
+	void setSourceModel(QAbstractItemModel *sourceModel);
 	Q_INVOKABLE void addAllDives();
 	Q_INVOKABLE void clear();
 public slots:
 	int getDiveId(int idx);
 	int getIdxForId(int id);
+	void setFilter(QString f);
+	void resetFilter();
+	int shown();
+	void updateDivesShownInTrips();
+protected:
+	bool filterAcceptsRow(int source_row, const QModelIndex &source_parent) const;
+private:
+	std::vector<unsigned char> filteredRows; // using unsigned char because using 'bool' turns this into a bitfield
+	QString filterString;
+	void updateFilterState();
 };
 
 class DiveListModel : public QAbstractListModel
@@ -26,7 +37,9 @@ public:
 
 	enum DiveListRoles {
 		DiveRole = Qt::UserRole + 1,
-		DiveDateRole
+		DiveDateRole,
+		FullTextRole,
+		FullTextNoNotesRole
 	};
 
 	static DiveListModel *instance();
