@@ -396,9 +396,9 @@ fi
 cd $SRC
 
 if [ "$BUILD_WITH_WEBKIT" = "1" ]; then
-	EXTRA_OPTS="-DNO_USERMANUAL=OFF -DFBSUPPORT=ON"
+	EXTRA_OPTS="-DNO_USERMANUAL=OFF"
 else
-	EXTRA_OPTS="-DNO_USERMANUAL=ON -DFBSUPPORT=OFF"
+	EXTRA_OPTS="-DNO_USERMANUAL=ON"
 fi
 
 if [ "$BUILDGRANTLEE" = "1" ] ; then
