@@ -46,9 +46,9 @@ git_checkout_library() {
 
 	if [ ! "$current_sha" = "$target_sha" ] ; then
 		git fetch origin
-		if ! git checkout "$version" ; then
+		if ! git checkout -f "$version" ; then
 			echo "Can't find the right tag in $name - giving up"
-			return 1
+			exit 1
 		fi
 	fi
 	popd
